| Title: | Provides a shiny app for workshop submissions |
|---|---|
| Description: | The package provides a form interface for submitting workshops via a shiny app. It requires a GitHub organization token for creating a comment on the Bioconductor/workshop-contributions repository. The package creates an issue and comments with the appropriate data from the form. |
| Authors: | Marcel Ramos [aut, cre] (ORCID: <https://orcid.org/0000-0002-3242-0582>), Alexandru Mahmoud [ctb] |
| Maintainer: | Marcel Ramos <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 0.99.14 |
| Built: | 2026-06-03 23:52:09 UTC |
| Source: | https://github.com/Bioconductor/BiocWorkshopSubmit |
Prepare a Bioconductor Workshop Submission
BiocWorkshopSubmit(...)BiocWorkshopSubmit(...)
... |
Arguments passed to |